@@ -1,7 +1,8 @@
 ##' Control a server for use with testing.  This is designed to be
 ##' used only by other packages that wish to run tests against a vault
-##' server.  You will need to set `VAULTR_TEST_SERVER_BIN_PATH`
-##' to point at the directory containing the vault binary.
+##' server.  You will need to set `VAULTR_TEST_SERVER_BIN_PATH` to
+##' point at the directory containing the vault binary, to the binary
+##' itself, or to the value `auto` to try and find it on your `PATH`.
 ##'
 ##' Once created with `vault_test_server`, a server will stay
 ##' alive for as long as the R process is alive *or* until the
@@ -10,41 +11,15 @@
 ##' the server, but this is not strictly needed.  See below for
 ##' methods to control the server instance.
 ##'
-##' The function `vault_test_server_install` will install a test
-##' server, but *only* if the user sets the following environmental
-##' variables:
-##'
-##' * `VAULTR_TEST_SERVER_INSTALL` to `"true"` to opt in to the
-##'   download.
-##'
-##' * `VAULTR_TEST_SERVER_BIN_PATH` to the directory where the binary
-##'   should be downloaded to.
-##'
-##' * `NOT_CRAN` to `"true"` to indicate this is not running on CRAN
-##'   as it requires installation of a binary from a website.
-##'
-##' This will download a ~100MB binary from https://vaultproject.io
-##' so use with care.  It is intended *only* for use in automated
-##' testing environments.
-##'
 ##' @section Warning:
 ##'
 ##' Starting a server in test mode must *not* be used for production
 ##'   under any circumstances.  As the name suggests,
 ##'   `vault_test_server` is a server suitable for *tests* only and
-##'   lacks any of the features required to make vault secure.  Please
-##'   see https://www.vaultproject.io/docs/concepts/dev-server.html
-##'   for more information
-##'
-##' @section Warning:
-##'
-##' The `vault_test_server_install` function will download a
-##'   binary from HashiCorp in order to use a vault server.  Use this
-##'   function with care.  The download will happen from
-##'   https://releases.hashicorp.com/vault (over https).  This
-##'   function is primarily designed to be used from continuous
-##'   integration services only and for local use you are strongly
-##'   recommended to curate your own installations.
+##'   lacks any of the features required to make vault secure.  For
+##'   more information, please see the the official Vault
+##'   documentation on development servers:
+##'   https://developer.hashicorp.com/vault/docs/concepts/dev-server
 ##'
 ##' @title Control a test vault server
 ##'
@@ -61,6 +36,9 @@
 ##'   `testthat::skip`.  Alternatively, inspect the
 ##'   `$enabled` property of the returned object.
 ##'
+##' @param quiet Logical, indicating if startup should be quiet and
+##'   not print messages
+##'
 ##' @export
 ##' @rdname vault_test_server
 ##' @aliases vault_server_instance
@@ -89,49 +67,9 @@
 ##'   tryCatch(client$status(), error = function(e) message(e$message))
 ##' }
 vault_test_server <- function(https = FALSE, init = TRUE,
-                              if_disabled = testthat::skip) {
-  global_vault_server_manager()$new_server(https, init, if_disabled)
-}
-
-
-##' @rdname vault_test_server
-##'
-##' @param quiet Suppress progress bars on install
-##'
-##' @param path Path in which to install vault test server. Leave as
-##'   `NULL` to use the `VAULTR_TEST_SERVER_BIN_PATH` environment
-##'   variable.
-##'
-##' @param version Version of vault to install
-##'
-##' @param platform For testing, overwrite the platform vault is being
-##'   installed on, with either "windows", "darwin" or "linux".
-##'
-##' @export
-vault_test_server_install <- function(path = NULL, quiet = FALSE,
-                                      version = "1.0.0",
-                                      platform = vault_platform()) {
-  if (!identical(Sys.getenv("NOT_CRAN"), "true")) {
-    stop("Do not run this on CRAN")
-  }
-  if (!identical(Sys.getenv("VAULTR_TEST_SERVER_INSTALL"), "true")) {
-    stop("Please read the documentation for vault_test_server_install")
-  }
-  if (is.null(path)) {
-    path <- Sys_getenv("VAULTR_TEST_SERVER_BIN_PATH", NULL)
-    if (is.null(path)) {
-      stop("VAULTR_TEST_SERVER_BIN_PATH is not set")
-    }
-  }
-
-  dir_create(path)
-  dest <- file.path(path, vault_exe_filename(platform))
-  if (file.exists(dest)) {
-    message("vault already installed at ", dest)
-  } else {
-    vault_install(path, quiet, version, platform)
-  }
-  invisible(dest)
+                              if_disabled = testthat::skip,
+                              quiet = FALSE) {
+  global_vault_server_manager()$new_server(https, init, if_disabled, quiet)
 }
 
 
@@ -153,10 +91,20 @@ vault_server_manager_bin <- function() {
   if (is.null(path)) {
     return(NULL)
   }
-  if (!file.exists(path) || !is_directory(path)) {
+  if (identical(path, "auto")) {
+    path <- unname(Sys.which("vault"))
+    if (!nzchar(path)) {
+      return(NULL)
+    }
+  }
+  if (!file.exists(path)) {
     return(NULL)
   }
-  bin <- file.path(path, vault_exe_filename())
+  if (is_directory(path)) {
+    bin <- file.path(path, vault_exe_filename())
+  } else {
+    bin <- path
+  }
   if (!file.exists(bin)) {
     return(NULL)
   }
@@ -204,15 +152,18 @@ vault_server_manager <- R6::R6Class(
     },
 
     new_server = function(https = FALSE, init = TRUE,
-                          if_disabled = testthat::skip) {
+                          if_disabled = testthat::skip,
+                          quiet = FALSE) {
       if (!self$enabled) {
         if_disabled("vault is not enabled")
       } else {
         tryCatch(
-          vault_server_instance$new(self$bin, self$new_port(), https, init),
-          error = function(e)
+          vault_server_instance$new(self$bin, self$new_port(), https, init,
+                                    quiet),
+          error = function(e) {
             testthat::skip(paste("vault server failed to start:",
-                                 e$message)))
+                                 e$message))
+          })
       }
     }
   ))
@@ -226,7 +177,8 @@ fake_token <- function() {
 }
 
 
-vault_server_wait <- function(test, process, timeout = 5, poll = 0.05) {
+vault_server_wait <- function(test, process, timeout = 5, poll = 0.05,
+                              quiet = FALSE) {
   t1 <- Sys.time() + timeout
   repeat {
     ok <- tryCatch(test(), error = function(e) FALSE)
@@ -237,13 +189,13 @@ vault_server_wait <- function(test, process, timeout = 5, poll = 0.05) {
       err <- paste(readLines(process$get_error_file()), collapse = "\n")
       stop("vault has died:\n", err)
     }
-    message("...waiting for Vault to start")
+    message_quietly("...waiting for Vault to start", quiet = quiet)
     Sys.sleep(poll)
   }
 }
 
 
-vault_server_start_dev <- function(bin, port) {
+vault_server_start_dev <- function(bin, port, quiet) {
   token <- fake_token()
   args <- c("server", "-dev",
             sprintf("-dev-listen-address=127.0.0.1:%s", port),
@@ -257,7 +209,7 @@ vault_server_start_dev <- function(bin, port) {
   addr <- sprintf("http://127.0.0.1:%d", port)
 
   cl <- vault_client(addr = addr)
-  vault_server_wait(cl$operator$is_initialized, process)
+  vault_server_wait(cl$operator$is_initialized, process, quiet = quiet)
   on.exit()
 
   for (i in 1:5) {
@@ -272,7 +224,7 @@ vault_server_start_dev <- function(bin, port) {
     Sys.sleep(0.5) # nocov
   }
 
-  ## See https://www.vaultproject.io/docs/secrets/kv/kv-v2.html#setup
+  ## See https://developer.hashicorp.com/vault/docs/secrets/kv/kv-v2#setup
   ##
   ## > when running a dev-mode server, the v2 kv secrets engine is
   ## > enabled by default at the path secret/ (for non-dev servers, it
@@ -291,7 +243,7 @@ vault_server_start_dev <- function(bin, port) {
 }
 
 
-vault_server_start_https <- function(bin, port, init) {
+vault_server_start_https <- function(bin, port, init, quiet) {
   ## Create a server configuration:
   config_path <- system.file("server", package = "vaultr", mustWork = TRUE)
   cfg <- readLines(file.path(config_path, "vault-tls.hcl"))
@@ -313,7 +265,8 @@ vault_server_start_https <- function(bin, port, init) {
   ## Here, our test function is a bit different because we're not
   ## expecting the server to be *initialised*, just to be ready to
   ## accept connections
-  vault_server_wait(function() !cl$operator$is_initialized(), process)
+  vault_server_wait(function() !cl$operator$is_initialized(), process,
+                    quiet = quiet)
 
   if (init) {
     res <- cl$operator$init(5, 3) # 5 / 3 key split
@@ -344,12 +297,6 @@ vault_platform <- function(sysname = Sys.info()[["sysname"]]) {
          stop("Unknown sysname"))
 }
 
-
-vault_url <- function(version, platform = vault_platform(), arch = "amd64") {
-  sprintf("https://releases.hashicorp.com/vault/%s/vault_%s_%s_%s.zip",
-          version, version, platform, arch)
-}
-
 vault_exe_filename <- function(platform = vault_platform()) {
   if (platform == "windows") {
     "vault.exe"
@@ -357,21 +304,3 @@ vault_exe_filename <- function(platform = vault_platform()) {
     "vault"
   }
 }
-
-
-vault_install <- function(dest, quiet, version, platform = vault_platform()) {
-  dest_bin <- file.path(dest, vault_exe_filename(platform))
-  if (!file.exists(dest_bin)) {
-    message(sprintf("installing vault to '%s'", dest))
-    url <- vault_url(version, platform)
-    zip <- download_file(url, quiet = quiet)
-    tmp <- tempfile()
-    dir_create(tmp)
-    utils::unzip(zip, exdir = tmp)
-    file_copy(file.path(tmp, vault_exe_filename(platform)), dest_bin)
-    unlink(tmp, recursive = TRUE)
-    file.remove(zip)
-    Sys.chmod(dest_bin, "755")
-  }
-  invisible(dest_bin)
-}
