@@ -1,7 +1,5 @@
-context("vault: auth: approle")
-
 test_that("approle", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$auth$enable("approle")
 
@@ -15,7 +13,7 @@ test_that("approle", {
 
 
 test_that("approle auth", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$auth$enable("approle")
 
@@ -26,10 +24,10 @@ test_that("approle auth", {
   expect_equal(ar$role_list(), role_name)
 
   d <- ar$role_read(role_name)
-  expect_is(d, "list")
+  expect_type(d, "list")
 
   role_id <- ar$role_id_read(role_name)
-  expect_is(role_id, "character")
+  expect_type(role_id, "character")
   expect_equal(length(role_id), 1L)
 
   secret <- ar$secret_id_generate(role_name)
@@ -37,29 +35,29 @@ test_that("approle auth", {
   auth <- ar$login(role_id, secret$id)
 
   token <- auth$client_token
-  expect_is(token, "character")
+  expect_type(token, "character")
 
   cl2 <- srv$client(login = FALSE)
-  expect_error(cl2$login(token = token), NA)
+  expect_error(cl2$login(token = token, quiet = TRUE), NA)
 })
 
 
 test_that("custom mount", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$auth$enable("approle", path = "approle2")
   ar <- cl$auth$approle$custom_mount("approle2")
-  expect_is(ar, "vault_client_auth_approle")
+  expect_s3_class(ar, "vault_client_auth_approle")
 
   ar$role_write("server")
-  expect_is(ar$role_read("server"), "list")
+  expect_type(ar$role_read("server"), "list")
   expect_error(cl$auth$approle$role_read("server"))
 })
 
 
 test_that("full login", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$auth$enable("approle")
   cl$write("/secret/test", list(a = 1))
@@ -76,14 +74,15 @@ test_that("full login", {
   cl2 <- srv$client(login = FALSE)
   cl2$login(method = "approle",
             role_id = role_id,
-            secret_id = secret$id)
+            secret_id = secret$id,
+            quiet = TRUE)
   expect_equal(cl2$read("/secret/test"), list(a = 1))
   expect_error(cl2$write("/secret/test", list(a = 2)))
 })
 
 
 test_that("role delete", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$auth$enable("approle")
 
@@ -98,7 +97,7 @@ test_that("role delete", {
 
 
 test_that("role set id", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$auth$enable("approle")
 
@@ -113,7 +112,7 @@ test_that("role set id", {
 
 
 test_that("secret id list", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$auth$enable("approle")
 
@@ -131,7 +130,7 @@ test_that("secret id list", {
 
 
 test_that("secret id read", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$auth$enable("approle")
 
@@ -150,7 +149,7 @@ test_that("secret id read", {
 
 
 test_that("secret id delete", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$auth$enable("approle")
 
