@@ -1,10 +1,7 @@
-context("vault: auth")
-
-
 test_that("auth", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
-  expect_is(cl$auth, "vault_client_auth")
+  expect_s3_class(cl$auth, "vault_client_auth")
   d <- cl$auth$list()
   expect_equal(d$path, "token/")
   expect_equal(d$type, "token")
@@ -14,9 +11,9 @@ test_that("auth", {
 
 
 test_that("introspect methods", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   expect_setequal(cl$auth$backends(),
-                  c("token", "github", "userpass", "approle"))
+                  c("token", "github", "ldap", "userpass", "approle"))
 })
