@@ -1,7 +1,5 @@
-context("vault: kv2")
-
 test_that("basic set/get", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -14,7 +12,7 @@ test_that("basic set/get", {
   data <- list(key = rand_str(10))
   meta <- kv$put(path, data)
 
-  expect_is(meta, "list")
+  expect_type(meta, "list")
   expect_equal(meta$version, 1L)
 
   expect_equal(kv$get(path), data)
@@ -25,7 +23,7 @@ test_that("basic set/get", {
 
 
 test_that("config", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -34,14 +32,14 @@ test_that("config", {
   wait_kv_upgrade(kv, p)
 
   config <- kv$config(p)
-  expect_is(config, "list")
+  expect_type(config, "list")
   expect_equal(config$cas_required, FALSE)
   expect_equal(config$max_versions, 0)
 })
 
 
 test_that("versions", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -65,7 +63,7 @@ test_that("versions", {
 
 
 test_that("delete latest version", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -90,7 +88,7 @@ test_that("delete latest version", {
 
 
 test_that("delete multiple versions", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -115,7 +113,7 @@ test_that("delete multiple versions", {
 
 
 test_that("list", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -138,7 +136,7 @@ test_that("list", {
 
 
 test_that("undelete", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -159,7 +157,7 @@ test_that("undelete", {
 
 
 test_that("destroy", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -180,7 +178,7 @@ test_that("destroy", {
 
 
 test_that("metadata put", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -199,7 +197,7 @@ test_that("metadata put", {
 
 
 test_that("metadata delete", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   p <- rand_str(10)
@@ -219,12 +217,12 @@ test_that("metadata delete", {
 
 
 test_that("mount validation", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("kv", "secret2", version = 2)
   kv <- cl$secrets$kv2$custom_mount("secret2")
-  wait_kv_upgrade(kv, p)
+  wait_kv_upgrade(kv, "secret2")
 
   expect_error(
     kv$list("/secret"),
@@ -236,12 +234,12 @@ test_that("mount validation", {
 
 
 test_that("put+cas", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("kv", "secret2", version = 2)
   kv <- cl$secrets$kv2$custom_mount("secret2")
-  wait_kv_upgrade(kv, p)
+  wait_kv_upgrade(kv, "secret2")
 
   d <- kv$put("secret2/a", list(a = 1))
   expect_error(kv$put("secret2/a", list(a = 2), cas = 2))
