@@ -1,19 +1,16 @@
-context("vault: operator")
-
-
 test_that("rekey", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   ans <- cl$operator$rekey_start(5, 3)
-  expect_is(ans$nonce, "character")
+  expect_type(ans$nonce, "character")
   expect_true(ans$started)
   expect_equal(ans$progress, 0)
   expect_equal(ans$required, 1)
 
   res <- cl$operator$rekey_submit(srv$keys[[1]], ans$nonce)
-  expect_is(res$keys, "character")
-  expect_is(res$keys_base64, "character")
+  expect_type(res$keys, "character")
+  expect_type(res$keys_base64, "character")
   expect_equal(length(res$keys), 5)
   expect_equal(length(res$keys_base64), 5)
 
@@ -28,15 +25,15 @@ test_that("rekey", {
     list(started = TRUE, progress = 2, required = 3))
   res <- cl$operator$rekey_submit(res$keys_base64[[3]], ans$nonce)
   expect_true(res$complete)
-  expect_is(res$keys, "character")
-  expect_is(res$keys_base64, "character")
+  expect_type(res$keys, "character")
+  expect_type(res$keys_base64, "character")
   expect_equal(length(res$keys), 5)
   expect_equal(length(res$keys_base64), 5)
 })
 
 
 test_that("cancel rekey", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   ans <- cl$operator$rekey_start(5, 3)
@@ -52,12 +49,12 @@ test_that("cancel rekey", {
 
 test_that("init", {
   skip_on_os("windows")
-  srv <- vault_test_server(https = TRUE, init = FALSE)
+  srv <- test_vault_test_server(https = TRUE, init = FALSE)
   cl <- srv$client(login = FALSE)
 
   dat <- cl$operator$init(5, 3)
-  expect_is(dat$keys, "character")
-  expect_is(dat$keys_base64, "character")
+  expect_type(dat$keys, "character")
+  expect_type(dat$keys_base64, "character")
   expect_equal(length(dat$keys), 5)
   expect_equal(length(dat$keys_base64), 5)
 
@@ -72,7 +69,7 @@ test_that("init", {
 
 
 test_that("seal", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   expect_false(cl$operator$seal_status()$sealed)
@@ -82,7 +79,7 @@ test_that("seal", {
 
 
 test_that("rotate", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   d1 <- cl$operator$key_status()
@@ -95,7 +92,7 @@ test_that("rotate", {
 
 
 test_that("leader status", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   d <- cl$operator$leader_status()
