@@ -1,19 +1,16 @@
-context("vault: policy")
-
-
 test_that("read policy", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   ## There's not much we can take from this one yet - this gets a
   ## better test after we start *writing* policies
   rules <- cl$policy$read("default")
-  expect_is(rules, "character")
+  expect_type(rules, "character")
 })
 
 
 test_that("write_policy", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   rules <- paste('path "secret/*" {',
