@@ -1,12 +1,9 @@
-context("vault: secrets")
-
-
 test_that("secrets", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
-  expect_is(cl$secrets, "vault_client_secrets")
+  expect_s3_class(cl$secrets, "vault_client_secrets")
   d <- cl$secrets$list()
-  expect_is(d, "data.frame")
+  expect_s3_class(d, "data.frame")
   expect_true("secret/" %in% d$path)
   expect_true("kv" %in% d$type)
   expect_error(cl$secrets$list(TRUE),
@@ -15,7 +12,7 @@ test_that("secrets", {
 
 
 test_that("enable/disable a secret engine", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$secrets$enable("kv", version = 2)
   d <- cl$secrets$list()
@@ -28,14 +25,17 @@ test_that("enable/disable a secret engine", {
 
 
 test_that("move a secret engine", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
-  p1 <- rand_str(10)
-  p2 <- rand_str(10)
+  p1 <- "oldpath"
+  p2 <- "newpath"
   cl$secrets$enable("kv", p1, version = 2)
+  # On CI, these tests are being flakey, and it's not at all obvious
+  # why; it could be a race condition so adding a little sleep here to see.
+  Sys.sleep(1)
   cl$secrets$move(p1, p2)
+  Sys.sleep(1)
   d <- cl$secrets$list()
-  cl$secrets$disable(p2)
   expect_true(paste0(p2, "/") %in% d$path)
   expect_false(paste0(p1, "/") %in% d$path)
 })
