@@ -1,20 +1,17 @@
-context("secret: transit")
-
-
 test_that("custom mount", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit", path = "transit2")
   tr <- cl$secrets$transit$custom_mount("transit2")
-  expect_is(tr, "vault_client_transit")
+  expect_s3_class(tr, "vault_client_transit")
 
-  expect_is(tr$random(format = "raw"), "raw")
+  expect_type(tr$random(format = "raw"), "raw")
 })
 
 
 test_that("basic key create/list/update/delete", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -24,7 +21,7 @@ test_that("basic key create/list/update/delete", {
   expect_equal(transit$key_list(), "test")
   transit$key_update("test", deletion_allowed = TRUE)
   info <- transit$key_read("test")
-  expect_is(info, "list")
+  expect_type(info, "list")
   expect_true(info$deletion_allowed)
   expect_null(transit$key_delete("test"))
   expect_equal(transit$key_list(), character(0))
@@ -32,7 +29,7 @@ test_that("basic key create/list/update/delete", {
 
 
 test_that("key rotate", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -45,7 +42,7 @@ test_that("key rotate", {
 
 
 test_that("encrypt data", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -56,13 +53,13 @@ test_that("encrypt data", {
   cyphertext <- transit$data_encrypt("test", charToRaw(plaintext))
 
   res <- transit$data_decrypt("test", cyphertext)
-  expect_is(res, "raw")
+  expect_type(res, "raw")
   expect_identical(res, charToRaw(plaintext))
 })
 
 
 test_that("rewrap data", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -84,7 +81,7 @@ test_that("rewrap data", {
 
 
 test_that("datakey", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -102,7 +99,7 @@ test_that("datakey", {
 
 ## duplicated tests from tools
 test_that("random", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$secrets$enable("transit")
   transit <- cl$secrets$transit
@@ -114,13 +111,13 @@ test_that("random", {
   expect_equal(nchar(res), 44)
 
   res <- transit$random(format = "raw")
-  expect_is(res, "raw")
+  expect_type(res, "raw")
   expect_equal(length(res), 32)
 })
 
 
 test_that("hash", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
   cl$secrets$enable("transit")
   transit <- cl$secrets$transit
@@ -154,7 +151,7 @@ test_that("hash", {
 
 
 test_that("hmac", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -170,7 +167,7 @@ test_that("hmac", {
 
 
 test_that("sign", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -186,7 +183,7 @@ test_that("sign", {
 
 
 test_that("backup", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -197,7 +194,7 @@ test_that("backup", {
   cyphertext <- transit$data_encrypt("test", plaintext)
 
   key <- transit$key_backup("test")
-  expect_is(key, "character")
+  expect_type(key, "character")
 
   transit$key_restore("restored", key)
   expect_identical(transit$data_decrypt("restored", cyphertext), plaintext)
@@ -205,7 +202,7 @@ test_that("backup", {
 
 
 test_that("export", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -214,14 +211,14 @@ test_that("export", {
 
 
   k <- transit$key_export("test", "encryption-key", NULL)
-  expect_is(k, "character")
+  expect_type(k, "character")
   expect_equal(transit$key_export("test", "encryption-key", 1),
                setNames(list(k), "1"))
 })
 
 
 test_that("key trim", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   skip_if_vault_before("1.0.0", srv, "/transit/keys/:name/trim",
                        "Key trimming")
   cl <- srv$client()
@@ -250,7 +247,7 @@ test_that("key trim", {
 
 
 test_that("key derivation: encrypt/decrypt", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -269,7 +266,7 @@ test_that("key derivation: encrypt/decrypt", {
 
 
 test_that("key derivation: rewrap", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -296,7 +293,7 @@ test_that("key derivation: rewrap", {
 
 
 test_that("key derivation: datakey", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
@@ -312,7 +309,7 @@ test_that("key derivation: datakey", {
 
 
 test_that("key derivation: sign/verify", {
-  srv <- vault_test_server()
+  srv <- test_vault_test_server()
   cl <- srv$client()
 
   cl$secrets$enable("transit")
